==> dde-dock_5.4.10.orig.tar.xz: dde-dock-5.4.10/translations/dde-dock_hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="hu" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>A %1 bővítmény nem kompatibilis a rendszerrel.</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Eltávolítás</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth beállítások</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Kikapcsolás</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Bekapcsolás</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth beállítások</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 kapcsolódva</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Kapcsolódás...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Kikapcsolva</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Billentyűzetkiosztás megadása</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Dátum és idő</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12 órás időformátum</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24 órás időformátum</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Idő beállításai</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <source>Enable network</source>
        <translation>Hálózat engedélyezése</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Hálózat letiltása</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Hálózati beállítások</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Biztosan törölni akarja a %1 elemet?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Ezt a műveletet nem lehet visszaállítani</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Ismeretlen eszköz</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Ismeretlen kötet</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Lemez</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Megnyitás</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Összes lecsatolása</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Indító</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Stílusos mód</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Hatékony mód</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Fent</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Lent</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Bal</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Jobb</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Megjelenítve tartás</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Elrejtve tartás</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Intelligens elrejtés</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mód</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Hely</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Állapot</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>Bővítmények</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Többfeladatos nézet</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Eltávolítás a Dokkolóról</translation>
    </message>
</context>
<context>
    <name>NetworkItem</name>
    <message>
        <source>Disable wired connection</source>
        <translation>Vezetékes kapcsolat megszüntetése</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Vezetékes kapcsolat engedélyezése</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Vezeték nélküli kapcsolat megszüntetése</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Vezeték nélküli kapcsolat engedélyezése</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Hálózat letiltása</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Hálózat engedélyezése</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Hálózati beállítások</translation>
    </message>
    <message>
        <source>Device disabled</source>
        <translation>Eszköz letiltva</translation>
    </message>
    <message>
        <source>Wireless connection: %1</source>
        <translation>Vezeték nélküli kapcsolat: %1</translation>
    </message>
    <message>
        <source>Wired connection: %1</source>
        <translation>Vezetékes kapcsolat: %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Nincs csatlakozva</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Csatlakozás</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Csatlakoztatva, de nincs internet hozzáférés</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Hálózati kábel kihúzva</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Vezeték nélküli hálózat</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Vezetékes hálózat </translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>A kapcsolódás sikertelen</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Hálózat</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Vezetékes hálózat </translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Vezetékes hálózat %1</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Virtuális billentyűzet</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Beállítások</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Kikapcsolás</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Energiagazdálkodási beállítások</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Akkumulátor töltöttsége %1, %2 perc van még hátra a feltöltésig</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Akkumulátor töltöttsége %1, %2 óra %3 perc van még hátra a feltöltésig</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Töltés %1, %2 perc van a feltöltés befejezéséig</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Töltés %1, %2 óra %3 perc van a feltöltés befejezéséig</translation>
    </message>
    <message>
        <source>Charged</source>
        <translation>Feltöltve</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Akkumulátor töltöttsége %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Töltés %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Akkumulátor töltöttsége %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Akkumulátor töltöttsége %1, teljesen feltöltve</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Asztal megjelenítése</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Eltávolítás a Dokkolóról</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Kikapcsolás</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Leállítás</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Alvó állapot</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernálás</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Zárolás</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Kijelentkezés</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Felhasználóváltás</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Energiagazdálkodási beállítások</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Újraindítás</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Eszköz</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Némítás visszavonása</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Némítás</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Hang beállítások</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Hangerő: %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Hang</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Kuka</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Kukában: %1 fájl</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Kukában: %1 fájl</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Megnyitás</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Ürítés</translation>
    </message>
</context>
<context>
    <name>TrayPlugin</name>
    <message>
        <source>System Tray</source>
        <translation>Rendszertálca</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <source>Wireless Network</source>
        <translation>Vezeték nélküli hálózat</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Vezeték nélküli hálózat %1 </translation>
    </message>
</context>
</TS>

==> dde-dock_5.5.38.orig.tar.xz: dde-dock-5.5.38/translations/dde-dock_hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>A %1 bővítmény nem kompatibilis a rendszerrel.</translation>
    </message>
</context>
<context>
    <name>AirplaneModeApplet</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Repülőgép üzemmód</translation>
    </message>
</context>
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>A repülőgép üzemmód engedélyezve</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Kikapcsolás</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Bekapcsolás</translation>
    </message>
    <message>
        <source>Airplane Mode settings</source>
        <translation>Repülőgép üzemmód beállításai</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>A repülőgép üzemmód letiltva</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Repülőgép üzemmód</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Eltávolítás</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth beállítások</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Kikapcsolás</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Bekapcsolás</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth beállítások</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 kapcsolódva</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Kapcsolódás...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Kikapcsolva</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Billentyűzetkiosztás megadása</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Dátum és idő</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12 órás időformátum</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24 órás időformátum</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Idő beállításai</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Biztosan törölni akarja a %1 elemet?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Ezt a műveletet nem lehet visszaállítani</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Ismeretlen eszköz</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Ismeretlen kötet</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Lemez</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Megnyitás</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Összes lecsatolása</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Indító</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation>Kilépés a biztonságos módból</translation>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation>Dokkoló - Biztonságos mód</translation>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation>A Dokkoló biztonságos módban van. Kérjük lépjen ki a megfelelő megjelenítéshez</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Stílusos mód</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Hatékony mód</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Fent</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Lent</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Bal</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Jobb</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Megjelenítve tartás</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Elrejtve tartás</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Intelligens elrejtés</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mód</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Hely</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Állapot</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation>Dokkoló beállításai</translation>
    </message>
</context>
<context>
    <name>ModuleWidget</name>
    <message>
        <source>Size</source>
        <translation>Méret</translation>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>Többképernyős mód</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>Bővítmény terület</translation>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>Válassza ki, hogy mely ikonok jelenjenek meg a dokkolóban</translation>
    </message>
    <message>
        <source>Fashion mode</source>
        <translation>Stílusos mód</translation>
    </message>
    <message>
        <source>Efficient mode</source>
        <translation>Hatékony mód</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mód</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Fent</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Lent</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Bal</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Jobb</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Hely</translation>
    </message>
    <message>
        <source>Keep shown</source>
        <translation>Megjelenítve tartás</translation>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>Maradjon rejtett</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>Intelligens elrejtés</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Állapot</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Kicsi</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Nagy</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation>Dokkoló mutatása</translation>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation>A képernyőn, ahol a kurzor található</translation>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation>Csak a főképernyőn</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Többfeladatos nézet</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Eltávolítás a Dokkolóról</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Képernyő billentyűzet</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Beállítások</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Kikapcsolás</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Energiagazdálkodási beállítások</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Akkumulátor töltöttsége %1, %2 perc van még hátra a feltöltésig</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Akkumulátor töltöttsége %1, %2 óra %3 perc van még hátra a feltöltésig</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Töltés %1, %2 perc van a feltöltés befejezéséig</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Töltés %1, %2 óra %3 perc van a feltöltés befejezéséig</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Akkumulátor töltöttsége %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Töltés %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Akkumulátor töltöttsége %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Akkumulátor töltöttsége %1, teljesen feltöltve</translation>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <source>Dock</source>
        <translation>Dokkoló</translation>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Asztal megjelenítése</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Eltávolítás a Dokkolóról</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Kikapcsolás</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Leállítás</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Alvó állapot</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernálás</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Zárolás</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Kijelentkezés</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Felhasználóváltás</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Energiagazdálkodási beállítások</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Újraindítás</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Eszköz</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Némítás visszavonása</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Némítás</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Hang beállítások</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Hangerő: %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Hang</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Kuka</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Kukában: %1 fájl</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Kukában: %1 fájl</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation>Áthelyezés a Kukába</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Megnyitás</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Ürítés</translation>
    </message>
</context>
</TS>
